==> viha-5.15.tar.gz: viha-5.15/pohja.php <==
<?php

# Copyright (C) 2009 Riku Kalinen
# License conditions in the file lisenssi.html
# Lisenssiehdot tiedostossa lisenssi.html

$table = "XXX";
$file = basename(__FILE__);

include "common.php";
include "XXX-ok.php";

echo "
<html>
<head>
 <title>VIHA - Viestivlineet</title>
</head>
" . body_bgcolor() . "
<h1>" . ota_paivystys_nimi() . ", viestivlineiden ksittely</h1>
";

hallinnolliset_linkit();

$id = get_nro_0('id');
$jarjesto_id = get_nro_1('jarjesto_id');
$hlo_id = get_nro_0('hlo_id');
$XXX = get_txt('XXX');
$tunniste = get_txt('tunniste');
$selite = get_txt('selite');
$verkko_id = get_nro_1('verkko_id');
$ryhma_id = get_nro_1('ryhma_id');
$merkitty = get_nro_0('merkitty');
$vakuutettu = get_nro_0('vakuutettu');
$vara_akut = get_nro_0('vara_akut');
$XXX_tyyppi_id = get_nro_1('XXX_tyyppi_id');
$palaute = get_txt('palaute');
$lisavarusteet = get_txt('lisavarusteet');

$add = get_txt('add');
$clear = get_txt('clear');
$save = get_txt('save');
$confirm = get_txt('confirm');
$change = get_txt('change');
$remove = get_txt('remove');

oltava_sallittu($file, $table, $id);

if (($add != '') && saa_tehda("$file:add")) {
  $ret = XXX_add_ok($herja,s('alue'),
		    s('paivystys'),
		    $jarjesto_id,$hlo_id,$XXX,$tunniste,$verkko_id,
		    $ryhma_id,$XXX_tyyppi_id);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql =
      "INSERT INTO $table
       SET alue_id = " . s("alue") . ",
           paivystys_id = " . s("paivystys") . ",
           jarjesto_id = $jarjesto_id,
           hlo_id = $hlo_id,
           XXX = '$XXX',
           tunniste = '$tunniste',
           selite = '$selite',
           verkko_id = $verkko_id,
           ryhma_id = $ryhma_id,
           merkitty = $merkitty,
           vakuutettu = $vakuutettu,
           vara_akut = $vara_akut,
           XXX_tyyppi_id = $XXX_tyyppi_id,
           palaute = '$palaute',
           lisavarusteet = '$lisavarusteet',
           ts = '$now'";
    $result = my_mysql_query ($sql);
    print "<p>Tiedot listty.\n";
    $clear = "ADD";
    loki("$sql id=" . last_insert_id());
    taktinen_loki("Listty viestivline $XXX ($tunniste)");
  }
  p_herja($ret,$herja);
 } # add

if (($save != '') && saa_tehda("$file:save")) {
  $ret = XXX_save_ok($herja,$id,s('alue'),
		     s('paivystys'),
		     $jarjesto_id,$hlo_id,$XXX,$tunniste,$verkko_id,
		     $ryhma_id,$XXX_tyyppi_id);
  $clear = "SAVE";
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql =
      "UPDATE $table
       SET alue_id = " . s("alue") . ",
           paivystys_id=" . s("paivystys") . ",
           jarjesto_id=$jarjesto_id,
           hlo_id=$hlo_id,
           XXX='$XXX',
           tunniste='$tunniste',
           selite='$selite',
           verkko_id=$verkko_id,
           ryhma_id=$ryhma_id,
           merkitty=$merkitty,
           vakuutettu=$vakuutettu,
           vara_akut=$vara_akut,
           XXX_tyyppi_id=$XXX_tyyppi_id,
           palaute='$palaute',
           lisavarusteet='$lisavarusteet',
           ts='$now'
       WHERE id=$id";
    $result = my_mysql_query ($sql);
    print "<p>Tiedot pivitetty.\n";
    $clear = "SISINEN";
    loki($sql);
    taktinen_loki("Muutettu viestivlinett $XXX ($tunniste)");
  }
  p_herja($ret,$herja);
 } # save

if (($confirm != '') && saa_tehda("$file:confirm")) {
  $ret = XXX_remove_ok($herja,$id);
  if ($ret != 2) {
    $XXX = tab_col_id("XXX","",$id);
    $tunniste = tab_col_id("XXX","tunniste",$id);
    taktinen_loki("Poistetaan viestivlinett $XXX ($tunniste)");
    $now = date('Y-m-d H:i:s');
    $sql = "DELETE FROM $table WHERE id = $id";
    $result = my_mysql_query ($sql);
    print "<p>Tiedot poistettu.\n";
    $clear = "SISINEN";
    loki($sql);
  }
  p_herja($ret,$herja);
 }

if ($clear != '') {
  $id = '0';
  $jarjesto_id = '1';
  $hlo_id = '0';
  $XXX = '';
  $tunniste = '';
  $selite = '';
  $verkko_id = '1';
  $ryhma_id = '1';
  $merkitty = '0';
  $vakuutettu = '0';
  $vara_akut = '0';
  $XXX_tyyppi_id = '1';
  $palaute = '';
  $lisavarusteet = '';
 }

# readonly tells if the fields are readonly. if not, they are editable.
if ($remove != '') { $readonly = 1; } else { $readonly = 0; }

# removable tells if we can actually remove this record
if ($remove != '') {
  $removable = 0;
  $ret = XXX_remove_ok($herja,$id,false);
  if ($ret != 2) {
    $removable = 1;
  }
  p_herja($ret,$herja);
 }

print "<form action=\"\" method=\"GET\">\n";
print "<p><table border=0>\n";

if ($id != "0") {
  $result = my_mysql_query("SELECT * FROM $table WHERE id = $id");
  $a = mysql_fetch_array($result);
  $jarjesto_id = $a['jarjesto_id'];
  $hlo_id = $a['hlo_id'];
  $XXX = $a['XXX'];
  $tunniste = $a['tunniste'];
  $selite = $a['selite'];
  $verkko_id = $a['verkko_id'];
  $ryhma_id = $a['ryhma_id'];
  $merkitty = $a['merkitty'];
  $vakuutettu = $a['vakuutettu'];
  $vara_akut = $a['vara_akut'];
  $XXX_tyyppi_id = $a['XXX_tyyppi_id'];
  $palaute = $a['palaute'];
  $lisavarusteet = $a['lisavarusteet'];
}

print "<tr><td>Id:";
if ($id == "0") {
  print "<td>(tehdn uusi)\n";
} else {
  print "<td>$id\n";
}
print "<td><input type=\"hidden\" name=\"id\" size=8 maxlength=8";
print " value=\"$id\">\n";

print "<tr><td>Jrjest:";
if ($readonly) {
  print "<td>"
  . ota_yksi("SELECT jarjesto FROM jarjesto WHERE id = $jarjesto_id")
  . "\n";
} else {
  print "<td>\n";
  tee_valinta("jarjesto_id", $jarjesto_id, "jarjesto", "id",
	      "jarjesto", "ORDER BY jarjesto");
}

print "<tr><td>Yhdyshenkil:";
if ($readonly) {
  print "<td>"
  . ota_yksi_0("SELECT nimi FROM hlo WHERE id = $hlo_id",
	       $hlo_id, "EI KUKAAN")
  . "\n";
} else {
  print "<td>\n";
  tee_valinta_plus_0("hlo_id", $hlo_id, "hlo", "id",
		     "nimi", "ORDER BY nimi", "EI MIKN");
  echo " Tai omistaja, ellei laitteelle ole mritelty jrjest";
}

print "<tr><td>Laitteen tyyppi:";
if ($readonly) {
  print "<td>$XXX\n";
} else {
  print "<td><input type=\"text\" name=\"XXX\" size=32 maxlength=32";
  print " value=\"$XXX\">\n";
}

print "<tr><td>Tunniste:";
if ($readonly) {
  print "<td>$tunniste\n";
} else {
  print "<td><input type=\"text\" name=\"tunniste\" size=32 maxlength=32";
  print " value=\"$tunniste\"> Sarjanumero, puhelinnumero tai vastaava\n";
}

print "<tr><td>Listietoja:";
if ($readonly) {
  print "<td>$selite\n";
} else {
  print "<td><input type=\"text\" name=\"selite\" size=64 maxlength=64";
  print " value=\"$selite\">\n";
}

print "<tr><td>Ensisijainen verkko:";
if ($readonly) {
  print "<td>"
    . ota_yksi("SELECT verkko FROM verkko WHERE id = $verkko_id")
    . "\n";
} else {
  print "<td>\n";
  tee_valinta("verkko_id", $verkko_id, "verkko", "id", "verkko",
	      "ORDER BY verkko");
}

print "<tr><td>Ryhm:";
if ($readonly) {
  print "<td>"
    . ota_yksi("SELECT kutsu FROM ryhma WHERE id = $ryhma_id")
    . "\n";
} else {
  print "<td>\n";
  select_ryhma($ryhma_id);
}

print "<tr><td>Merkitty:";
if ($readonly) {
  print "<td>" . tab_col_id("juuei","",$merkitty) . "\n";
} else {
  print "<td>\n";
  tee_valinta("merkitty", $merkitty, "juuei", "id", "juuei", "ORDER BY juuei");
}

print "<tr><td>Vakuutettu:";
if ($readonly) {
  print "<td>" . tab_col_id("juuei","",$vakuutettu) . "\n";
} else {
  print "<td>\n";
  tee_valinta("vakuutettu", $vakuutettu, "juuei", "id", "juuei",
	      "ORDER BY juuei");
}

print "<tr><td>Vara-akut:";
if ($readonly) {
  print "<td>$vara_akut\n";
} else {
  print "<td><input type=\"text\" name=\"vara_akut\" size=8 maxlength=8";
  print " value=\"$vara_akut\"> Lukumr\n";
}

print "<tr><td>Laitteen tyyppi:";
if ($readonly) {
  print "<td>" . tab_col_id("XXX_tyyppi","",$XXX_tyyppi_id) . "\n";
} else {
  print "<td>\n";
  tee_valinta("XXX_tyyppi_id", $XXX_tyyppi_id, "XXX_tyyppi", "id",
	      "XXX_tyyppi", "ORDER BY XXX_tyyppi");
}

print "<tr><td>Palaute:";
if ($readonly) {
  print "<td>$palaute\n";
} else {
  print "<td><input type=\"text\" name=\"palaute\" size=64 maxlength=255";
  print " value=\"$palaute\">\n";
}

print "<tr><td>Lisvarusteet:";
if ($readonly) {
  print "<td>$lisavarusteet\n";
} else {
  print "<td><input type=\"text\" name=\"lisavarusteet\" size=64 maxlength=64";
  print " value=\"$lisavarusteet\">\n";
}

print "</table>\n";

if ($change != "") {
  echo "<input type=\"submit\" name=\"save\" value=\"TALLENNA\">\n";
  echo "<input type=\"submit\" name=\"clear\" value=\"PERUUTA\">\n";
} elseif ($remove != "") {
  if ($removable) {
    echo "<input type=\"submit\" name=\"confirm\" value=\"VAHVISTA POISTO\">\n";
  }
  echo "<input type=\"submit\" name=\"clear\" value=\"PERUUTA\">\n";
} else {
  echo "<input type=\"submit\" name=\"add\" value=\"LIS\">\n";
  echo "<input type=\"submit\" name=\"clear\" value=\"TYHJENN\">\n";
}

$sql =
  "SELECT $table.id, $table.ts, $table.XXX, $table.tunniste, $table.selite,
          $table.lisavarusteet, jarjesto_id,
          hlo_id, verkko_id, ryhma_id, merkitty, vakuutettu, vara_akut,
          XXX_tyyppi_id, palaute
   FROM $table
   ORDER BY $table.XXX, $table.tunniste";
$result = my_mysql_query($sql);
if ($result) {
  echo "<p><TABLE BORDER=1>\n";
  echo tr_bgcolor()
    . "<TH>Id<TH>Aikaleima<TH>Tyyppi<TH>Tunniste<TH>Selite<TH>List"
    . "<TH>Jrjest<TH>Henkil<TH>Verkko<TH>Ryhm"
    . "<TH>Merk<TH>Vak<TH>Akut<TH>Tyyppi<TH>Palaute\n";
  while ($a = mysql_fetch_array($result)) {
    # just skip those items we do not have permission to
    if (visible_operation_tab($herja,$table,$a['id'],false) == 2)
      continue; 
    echo "<TR><TD>$a[id]", "<TD>$a[ts]", "<TD>$a[XXX]", "<TD>$a[tunniste]",
      "<TD>$a[selite]", "<TD>$a[lisavarusteet]",
      "<TD>" . tab_col_id("jarjesto","",$a['jarjesto_id']),
      "<TD>" . tab_col_id_nobody("hlo","nimi",$a['hlo_id']),
      "<TD>" . tab_col_id("verkko","",$a['verkko_id']),
      "<TD>" . tab_col_id("ryhma","kutsu",$a['ryhma_id']),
      "<TD>" . tab_col_id("juuei","",$a['merkitty']),
      "<TD>" . tab_col_id("juuei","",$a['vakuutettu']),
      "<TD>$vara_akut",
      "<TD>" . tab_col_id("XXX_tyyppi","",$a['XXX_tyyppi_id']),
      "<TD>$a[palaute]";
    if ($id == "0") {
      echo "<td><a href=\"$file?id=$a[id]&change=MUUTA\">MUUTA</a>\n";
      echo "<td><a href=\"$file?id=$a[id]&remove=POISTA\">POISTA</a>\n";
    }
  }
  echo "</TABLE>";
} else {
  echo "<p>Plop. Ei XXXtietoja.";
}

print "</form>\n";

loppu();

?>
</body> 
</html>
<!-- RCS $Id: pohja.php,v 1.20 2009/05/04 05:17:31 riku Exp $ -->

==> viha-5.27.tar.gz: viha-5.27/pohja.php <==
<?php

# Copyright (C) 2009 Riku Kalinen
# License conditions in the file lisenssi.html
# Lisenssiehdot tiedostossa lisenssi.html

$table = "XXX";
$file = basename(__FILE__);

include "common.php";
include "XXX-ok.php";

echo "
<html>
<head>
 <title>VIHA - Viestivlineet</title>
</head>
" . body_bgcolor() . "
<h1>" . muotoile_operaatio() . ", viestivlineiden ksittely</h1>
";

hallinnolliset_linkit();

$id = get_nro_0('id');
$jarjesto_id = get_nro_1('jarjesto_id');
$hlo_id = get_nro_0('hlo_id');
$XXX = get_txt('XXX');
$tunniste = get_txt('tunniste');
$selite = get_txt('selite');
$verkko_id = get_nro_1('verkko_id');
$ryhma_id = get_nro_1('ryhma_id');
$merkitty = get_nro_0('merkitty');
$vakuutettu = get_nro_0('vakuutettu');
$vara_akut = get_nro_0('vara_akut');
$XXX_tyyppi_id = get_nro_1('XXX_tyyppi_id');
$palaute = get_txt('palaute');
$lisavarusteet = get_txt('lisavarusteet');

$add = get_txt('add');
$clear = get_txt('clear');
$save = get_txt('save');
$confirm = get_txt('confirm');
$change = get_txt('change');
$remove = get_txt('remove');

oltava_sallittu($file, $table, $id);

if (($add != '') && saa_tehda("$file:add")) {
  $ret = XXX_add_ok($herja,s('alue'),
		    s('paivystys'),
		    $jarjesto_id,$hlo_id,$XXX,$tunniste,$verkko_id,
		    $ryhma_id,$XXX_tyyppi_id);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql =
      "INSERT INTO $table
       SET alue_id = " . s("alue") . ",
           paivystys_id = " . s("paivystys") . ",
           jarjesto_id = $jarjesto_id,
           hlo_id = $hlo_id,
           XXX = '$XXX',
           tunniste = '$tunniste',
           selite = '$selite',
           verkko_id = $verkko_id,
           ryhma_id = $ryhma_id,
           merkitty = $merkitty,
           vakuutettu = $vakuutettu,
           vara_akut = $vara_akut,
           XXX_tyyppi_id = $XXX_tyyppi_id,
           palaute = '$palaute',
           lisavarusteet = '$lisavarusteet',
           ts = '$now'";
    $result = my_mysql_query ($sql);
    print "<p>XXX $xxx listty.\n";
    $clear = "ADD";
    loki("$sql id=" . last_insert_id());
    taktinen_loki("Listty viestivline $XXX ($tunniste)");
  }
  p_herja($ret,$herja);
 } # add

if (($save != '') && saa_tehda("$file:save")) {
  $ret = XXX_save_ok($herja,$id,s('alue'),
		     s('paivystys'),
		     $jarjesto_id,$hlo_id,$XXX,$tunniste,$verkko_id,
		     $ryhma_id,$XXX_tyyppi_id);
  $clear = "SAVE";
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql =
      "UPDATE $table
       SET alue_id = " . s("alue") . ",
           paivystys_id=" . s("paivystys") . ",
           jarjesto_id=$jarjesto_id,
           hlo_id=$hlo_id,
           XXX='$XXX',
           tunniste='$tunniste',
           selite='$selite',
           verkko_id=$verkko_id,
           ryhma_id=$ryhma_id,
           merkitty=$merkitty,
           vakuutettu=$vakuutettu,
           vara_akut=$vara_akut,
           XXX_tyyppi_id=$XXX_tyyppi_id,
           palaute='$palaute',
           lisavarusteet='$lisavarusteet',
           ts='$now'
       WHERE id=$id";
    $result = my_mysql_query ($sql);
    print "<p>XXX $xxx pivitetty.\n";
    $clear = "SISINEN";
    loki($sql);
    taktinen_loki("Muutettu viestivlinett $XXX ($tunniste)");
  }
  p_herja($ret,$herja);
 } # save

if (($confirm != '') && saa_tehda("$file:confirm")) {
  $ret = XXX_remove_ok($herja,$id);
  if ($ret != 2) {
    $XXX = tab_col_id("XXX","",$id);
    $tunniste = tab_col_id("XXX","tunniste",$id);
    taktinen_loki("Poistetaan viestivlinett $XXX ($tunniste)");
    $now = date('Y-m-d H:i:s');
    $sql = "DELETE FROM $table WHERE id = $id";
    $result = my_mysql_query ($sql);
    print "<p>Tiedot poistettu.\n";
    $clear = "SISINEN";
    loki($sql);
  }
  p_herja($ret,$herja);
 }

if ($clear != '') {
  $id = '0';
  $jarjesto_id = '1';
  $hlo_id = '0';
  $XXX = '';
  $tunniste = '';
  $selite = '';
  $verkko_id = '1';
  $ryhma_id = '1';
  $merkitty = '0';
  $vakuutettu = '0';
  $vara_akut = '0';
  $XXX_tyyppi_id = '1';
  $palaute = '';
  $lisavarusteet = '';
 }

# readonly tells if the fields are readonly. if not, they are editable.
if ($remove != '') { $readonly = 1; } else { $readonly = 0; }

# removable tells if we can actually remove this record
if ($remove != '') {
  $removable = 0;
  $ret = XXX_remove_ok($herja,$id,false);
  if ($ret != 2) {
    $removable = 1;
  }
  p_herja($ret,$herja);
 }

print "<form action=\"\" method=\"GET\">\n";
print "<p><table border=0>\n";

if ($id != "0") {
  $result = my_mysql_query("SELECT * FROM $table WHERE id = $id");
  $a = mysql_fetch_array($result);
  $jarjesto_id = $a['jarjesto_id'];
  $hlo_id = $a['hlo_id'];
  $XXX = $a['XXX'];
  $tunniste = $a['tunniste'];
  $selite = $a['selite'];
  $verkko_id = $a['verkko_id'];
  $ryhma_id = $a['ryhma_id'];
  $merkitty = $a['merkitty'];
  $vakuutettu = $a['vakuutettu'];
  $vara_akut = $a['vara_akut'];
  $XXX_tyyppi_id = $a['XXX_tyyppi_id'];
  $palaute = $a['palaute'];
  $lisavarusteet = $a['lisavarusteet'];
}

print "<tr><td>Id:";
if ($id == "0") {
  print "<td>(tehdn uusi)\n";
} else {
  print "<td>$id\n";
}
print "<td><input type=\"hidden\" name=\"id\" size=8 maxlength=8";
print " value=\"$id\">\n";

print "<tr><td>Jrjest:";
if ($readonly) {
  print "<td>"
  . ota_yksi("SELECT jarjesto FROM jarjesto WHERE id = $jarjesto_id")
  . "\n";
} else {
  print "<td>\n";
  tee_valinta("jarjesto_id", $jarjesto_id, "jarjesto", "id",
	      "jarjesto", "ORDER BY jarjesto");
}

print "<tr><td>Yhdyshenkil:";
if ($readonly) {
  print "<td>"
  . ota_yksi_0("SELECT nimi FROM hlo WHERE id = $hlo_id",
	       $hlo_id, "EI KUKAAN")
  . "\n";
} else {
  print "<td>\n";
  tee_valinta_plus_0("hlo_id", $hlo_id, "hlo", "id",
		     "nimi", "ORDER BY nimi", "EI MIKN");
  echo " Tai omistaja, ellei laitteelle ole mritelty jrjest";
}

print "<tr><td>Laitteen tyyppi:";
if ($readonly) {
  print "<td>$XXX\n";
} else {
  print "<td><input type=\"text\" name=\"XXX\" size=32 maxlength=32";
  print " value=\"$XXX\">\n";
}

print "<tr><td>Tunniste:";
if ($readonly) {
  print "<td>$tunniste\n";
} else {
  print "<td><input type=\"text\" name=\"tunniste\" size=32 maxlength=32";
  print " value=\"$tunniste\"> Sarjanumero, puhelinnumero tai vastaava\n";
}

print "<tr><td>Listietoja:";
if ($readonly) {
  print "<td>$selite\n";
} else {
  print "<td><input type=\"text\" name=\"selite\" size=64 maxlength=64";
  print " value=\"$selite\">\n";
}

print "<tr><td>Ensisijainen verkko:";
if ($readonly) {
  print "<td>"
    . ota_yksi("SELECT verkko FROM verkko WHERE id = $verkko_id")
    . "\n";
} else {
  print "<td>\n";
  tee_valinta("verkko_id", $verkko_id, "verkko", "id", "verkko",
	      "ORDER BY verkko");
}

print "<tr><td>Ryhm:";
if ($readonly) {
  print "<td>"
    . ota_yksi("SELECT kutsu FROM ryhma WHERE id = $ryhma_id")
    . "\n";
} else {
  print "<td>\n";
  select_ryhma($ryhma_id);
}

print "<tr><td>Merkitty:";
if ($readonly) {
  print "<td>" . tab_col_id("juuei","",$merkitty) . "\n";
} else {
  print "<td>\n";
  tee_valinta("merkitty", $merkitty, "juuei", "id", "juuei", "ORDER BY juuei");
}

print "<tr><td>Vakuutettu:";
if ($readonly) {
  print "<td>" . tab_col_id("juuei","",$vakuutettu) . "\n";
} else {
  print "<td>\n";
  tee_valinta("vakuutettu", $vakuutettu, "juuei", "id", "juuei",
	      "ORDER BY juuei");
}

print "<tr><td>Vara-akut:";
if ($readonly) {
  print "<td>$vara_akut\n";
} else {
  print "<td><input type=\"text\" name=\"vara_akut\" size=8 maxlength=8";
  print " value=\"$vara_akut\"> Lukumr\n";
}

print "<tr><td>Laitteen tyyppi:";
if ($readonly) {
  print "<td>" . tab_col_id("XXX_tyyppi","",$XXX_tyyppi_id) . "\n";
} else {
  print "<td>\n";
  tee_valinta("XXX_tyyppi_id", $XXX_tyyppi_id, "XXX_tyyppi", "id",
	      "XXX_tyyppi", "ORDER BY XXX_tyyppi");
}

print "<tr><td>Palaute:";
if ($readonly) {
  print "<td>$palaute\n";
} else {
  print "<td><input type=\"text\" name=\"palaute\" size=64 maxlength=255";
  print " value=\"$palaute\">\n";
}

print "<tr><td>Lisvarusteet:";
if ($readonly) {
  print "<td>$lisavarusteet\n";
} else {
  print "<td><input type=\"text\" name=\"lisavarusteet\" size=64 maxlength=64";
  print " value=\"$lisavarusteet\">\n";
}

print "</table>\n";

if ($change != "") {
  echo "<input type=\"submit\" name=\"save\" value=\"TALLENNA\">\n";
  echo "<input type=\"submit\" name=\"clear\" value=\"PERUUTA\">\n";
} elseif ($remove != "") {
  if ($removable) {
    echo "<input type=\"submit\" name=\"confirm\" value=\"VAHVISTA POISTO\">\n";
  }
  echo "<input type=\"submit\" name=\"clear\" value=\"PERUUTA\">\n";
} else {
  echo "<input type=\"submit\" name=\"add\" value=\"LIS\">\n";
  echo "<input type=\"submit\" name=\"clear\" value=\"TYHJENN\">\n";
}

$sql =
  "SELECT $table.id, $table.ts, $table.XXX, $table.tunniste, $table.selite,
          $table.lisavarusteet, jarjesto_id,
          hlo_id, verkko_id, ryhma_id, merkitty, vakuutettu, vara_akut,
          XXX_tyyppi_id, palaute
   FROM $table
   ORDER BY $table.XXX, $table.tunniste";
$result = my_mysql_query($sql);
if ($result) {
  echo "<p><TABLE BORDER=1>\n";
  tr_reset();
  echo tr_vaalsin()
    . "<TH>Id<TH>Aikaleima<TH>Tyyppi<TH>Tunniste<TH>Selite<TH>List"
    . "<TH>Jrjest<TH>Henkil<TH>Verkko<TH>Ryhm"
    . "<TH>Merk<TH>Vak<TH>Akut<TH>Tyyppi<TH>Palaute\n";
  while ($a = mysql_fetch_array($result)) {
    # just skip those items we do not have permission to
    if (visible_operation_tab($herja,$table,$a['id'],false) == 2)
      continue; 
    echo tr() . "<TD>$a[id]", "<TD>$a[ts]", "<TD>$a[XXX]", "<TD>$a[tunniste]",
      "<TD>$a[selite]", "<TD>$a[lisavarusteet]",
      "<TD>" . tab_col_id("jarjesto","",$a['jarjesto_id']),
      "<TD>" . tab_col_id_nobody("hlo","nimi",$a['hlo_id']),
      "<TD>" . tab_col_id("verkko","",$a['verkko_id']),
      "<TD>" . tab_col_id("ryhma","kutsu",$a['ryhma_id']),
      "<TD>" . tab_col_id("juuei","",$a['merkitty']),
      "<TD>" . tab_col_id("juuei","",$a['vakuutettu']),
      "<TD>$vara_akut",
      "<TD>" . tab_col_id("XXX_tyyppi","",$a['XXX_tyyppi_id']),
      "<TD>$a[palaute]";
    if ($id == "0") {
      echo "<td><a href=\"$file?id=$a[id]&change=MUUTA\">MUUTA</a>\n";
      echo "<td><a href=\"$file?id=$a[id]&remove=POISTA\">POISTA</a>\n";
    }
  }
  echo "</TABLE>";
} else {
  echo "<p>Plop. Ei XXXtietoja.";
}

print "</form>\n";

loppu();

?>
</body> 
</html>
<!-- RCS $Id: pohja.php,v 1.23 2009/09/29 16:09:15 riku Exp $ -->
